@@ -1,11 +1,12 @@
 import functools
+import os
 from typing import Callable
 
 from simple_proxy2.data.observable import Observable
 from simple_proxy2.data.proxy_info import ProxyInfo
 
-delta = 0.0001
-count_diff = 10
+delta = float(os.getenv('PROXY_MANAGER_DELTA', '0.00001'))
+count_diff = int(os.getenv('PROXY_MANAGER_COUNT_DIFF', '5'))
 
 
 @functools.total_ordering
