@@ -160,7 +160,8 @@ class ProxyManager:
                     except Exception as ex:
                         exception_handle(proxy.info(), ex)
                     finally:
-                        proxy.update_response_time(timer.time_elapsed())
+                        proxy.update_response_time(
+                            timer.time_elapsed() if success else 999.0)
 
                         if success:
                             self._on_success()
@@ -211,14 +212,14 @@ class ProxyManager:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         loop = asyncio.get_event_loop()
-        return loop.run_until_complete(self.stop(False))
+        return loop.run_until_complete(self.stop(exc_type is None))
 
     async def __aenter__(self):
         await self.start()
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
-        return await self.stop(False)
+        return await self.stop(exc_type is None)
 
 
 class SessionProxy(Session):
